=============
vhr-composite
=============

.. image:: https://github.com/nasa-nccs-hpda/vhr-composite/actions/workflows/lint.yml/badge.svg
   :target: https://github.com/nasa-nccs-hpda/vhr-composite/actions/workflows/lint.yml
.. image:: https://zenodo.org/badge/617555319.svg
   :target: https://zenodo.org/badge/latestdoi/617555319

**Very High Resolution (VHR) Composite Tool**

* GitHub repo: https://github.com/nasa-nccs-hpda/vhr-composite
* Documentation: https://nasa-nccs-hpda.github.io/vhr-composite

Installation
------------

**vhr-composite** is available on `PyPI <https://pypi.org/project/eo-validation/>`__. To install **vhr-composite**, run this command in your terminal:

.. code:: python

  pip install vhr-composite
